@@ -1,4 +1,4 @@
-#Added by slkbuild 0.8.6
+#Added by slkbuild 1.4.3
 dotnew() {
         NEW="${1}.new"
         OLD="$1"
@@ -9,6 +9,8 @@ dotnew() {
         fi
 }
 dotnew etc/slkbuild/SLKBUILD
-dotnew etc/slkbuild/SLKBUILD.python
+dotnew etc/slkbuild/SLKBUILD.gconf
+dotnew etc/slkbuild/SLKBUILD.mateconf
 dotnew etc/slkbuild/SLKBUILD.perl
+dotnew etc/slkbuild/SLKBUILD.python
 dotnew etc/slkbuild/SLKBUILD.waf
